<?php
/**
 * Class WPAUST_WP_Enqueue
 *
 * This class is responsible for enqueuing admin and front-end styles and scripts, as well as 
 * localizing the AJAX script to ensure proper functionality and communication with 
 * the server.
 *
 * @package WP Author Status v2.0 - 30 January, 2025
 * @link https://www.realwebcare.com/
 */
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'WPAUST_WP_Enqueue' ) ) {
    class WPAUST_WP_Enqueue {

        // Hold the single instance of the class.
        private static $instance;

        // Constructor is private to enforce the Singleton pattern.
        private function __construct() {
            // Hook to enqueue styles for the plugin.
            add_action( 'wp_enqueue_scripts', array( $this, 'wpaust_enqueue_script' ) );

            // Add inline styles for the plugin.
            add_action( 'admin_enqueue_scripts', array( $this, 'author_status_style_admin' ) );
        }

        // Public static method to retrieve the singleton instance.
        public static function get_instances() {
            if ( self::$instance ) {
                return self::$instance;
            }

            self::$instance = new self();

            return self::$instance;
        }

        public function author_status_style_admin( $screen ) {
            $wpaust_pages = array(
                'index.php',
                'toplevel_page_wpaust-options',
                'author-status_page_wpaust-help',
            );

            if ( in_array( $screen, $wpaust_pages ) ) {
                wp_enqueue_script( 'wpaust-script', WPAUST_PLUGIN_URL . 'assets/js/wpaust-admin.js', array('jquery', 'wp-util'), '0.1', true );
                wp_enqueue_style('wpaust-style', WPAUST_PLUGIN_URL .'assets/css/wpaust-admin.css', array(), '0.1');
            }
        }

        // Enqueue styles for the plugin.
        public function wpaust_enqueue_script() {
            wp_enqueue_script( 'wpaust-script', WPAUST_PLUGIN_URL . 'assets/js/wpaust-script.js', array('jquery', 'wp-util'), '0.1', true );

            wp_enqueue_style( 'wpaust-style', WPAUST_PLUGIN_URL . 'assets/css/wpaust-style.css', array(), '0.1' );
        }
    }
}

// Instantiate the plugin class.
WPAUST_WP_Enqueue::get_instances();