<?php
/**
 * Class WPAUST_Help
 *
 * This file contains the help page for the "WP Author Status" plugin
 * in the admin panel. The help page provides instructions, and
 * assistance to administrators on how to use various features of the plugin.
 *
 * @package WP Author Status v2.0 - 30 January, 2025
 * @link https://www.realwebcare.com/
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'WPAUST_Help' ) ) {
	class WPAUST_Help {

		/**
		 * Render the help page.
		 */
		public function render_wpaust_help_page() { ?>
			<div class="wpaust_settings_area">
				<div class="wrap wpaust_settings">
					<h1 class="main-header">
						<?php esc_html_e('RWC User Front-End Guide', 'wp-author-status'); ?>
					</h1>
					<?php $this->render_wpaust_dashboard_guide(); ?>
					<?php $this->render_wpaust_status_guide(); ?>
				</div>
			</div>
            <?php
            $this->render_sidebar();
		}

		/**
		 * Render instructions for creating a new user front-end dashboard.
		 */
		public function render_wpaust_dashboard_guide() {
			?>
			<div class="wpaust-help-info">
				<h3 class="get-instructed">
					<?php
					printf(
						esc_html__(
							'Code Usage Instruction in the Theme',
							'wp-author-status'
						));
					?>
				</h3>
				<ol class="wpaust-help-instructions">
					<li>
						<?php
						printf(
							/* translators: 1: Opening strong tag, 2: Closing strong tag */
							esc_html__('To display the author status shortcode in a WordPress theme file, you can use the %1$sdo_shortcode%2$s function:', 'wp-author-status'), 
							'<strong>', '</strong>'
						); 
						?>
					</li>
					<li>
						<?php
						printf(
							/* translators: %s: Example of do_shortcode usage in a PHP code block */
							esc_html__('Example of shortcode usage in PHP: %s', 'wp-author-status'), 
							'<pre><code><span>&lt;?php</span> <span class="wpaust-keyword">echo</span> <span class="wpaust-function">do_shortcode</span>(<span class="wpaust-string">\'[wp-author-status]\'</span>); <span>?&gt;</span></code></pre>'
						);
						?>
					</li>
					<li>
						<?php
						printf(
							/* translators: 1: Opening strong tag, 2: Closing strong tag */
							esc_html__('You can place this code anywhere in your theme\'s %1$ssingle.php%2$s file where you want the author status to appear.', 'wp-author-status'), 
							'<strong>', '</strong>'
						); 
						?>
					</li>
					<li>
						<?php
						printf(
							/* translators: 1: Opening strong tag, 2: Closing strong tag */
							esc_html__('Keep in mind that if you are making changes directly to your theme files, those changes will be overwritten if you update the theme. To avoid this, you can create a %1$schild theme%2$s and make your changes there instead.', 'wp-author-status'), 
							'<strong>', '</strong>'
						); 
						?>
					</li>
				</ol>
			</div>
			<?php
		}

		/**
		 * Render instructions for creating a new user front-end dashboard.
		 */
		public function render_wpaust_status_guide() {
			?>
			<div class="wpaust-help-info">
				<h3 class="get-instructed">
					<?php
					esc_html_e('Guide to Using the Author Status Shortcode', 'wp-author-status');
					?>
				</h3>
				<ol class="wpaust-help-instructions">
					<li>
						<strong><?php esc_html_e('Add the Shortcode in a Widget:', 'wp-author-status'); ?></strong>
						<p><?php esc_html_e( 'To show the author status in your site\'s sidebar or any widget-ready area:', 'wp-author-status' ); ?></p>
						<ol>
							<li>
								<?php
								printf(
									/* translators: 1: Opening strong tag, 2: Closing strong tag, 3: Opening strong tag, 4: Closing strong tag */
									esc_html__('Go to %1$sAppearance%2$s → %3$sWidgets%4$s in your WordPress dashboard.', 'wp-author-status'), 
									'<strong>', '</strong>', '<strong>', '</strong>'
								);
								?>
							</li>
							<li>
								<?php
								printf(
									/* translators: 1: Opening strong tag, 2: Closing strong tag */
									esc_html__('If you are using the %1$sClassic Widget%2$s Editor:', 'wp-author-status'),
									'<strong>', '</strong>'
								);
								?>
								<p>
									<?php
										printf(
											/* translators: 1: Opening strong tag, 2: Closing strong tag, 3: Opening strong tag, 4: Closing strong tag */
											esc_html__( 'Drag and drop a %1$sText%2$s or %3$sCustom HTML%4$s widget into your desired widget area (e.g., Sidebar or Footer).', 'wp-author-status' ),
											'<strong>', '</strong>', '<strong>', '</strong>'
										);
									?>
								</p>
							</li>
							<li>
								<?php
								printf(
									/* translators: 1: Opening strong tag, 2: Closing strong tag */
									esc_html__('If you are using the %1$sBlock Widget%2$s Editor:', 'wp-author-status'),
									'<strong>', '</strong>'
								);
								?>
								<p>
									<?php
										printf(
											/* translators: 1: Opening strong tag, 2: Closing strong tag */
											esc_html__('Add a %1$s[/] Shortcode%2$s block to your desired widget area.', 'wp-author-status'),
											'<strong>', '</strong>'
										);
									?>
								</p>
							</li>
							<li>
								<?php
								printf(
									/* translators: 1: Opening code tag, 2: Closing code tag */
									esc_html__('Paste the shortcode %1$s[wp-author-status]%2$s inside the widget or block and save.', 'wp-author-status'),
									'<code>', '</code>'
								);
								?>
							</li>
							<li>
								<?php
								printf(
                                    /* translators: 1: Opening strong tag, 2: Closing strong tag, 3: Opening strong tag, 4: Closing strong tag */
                                    esc_html__(
                                        'Please ensure you add the %1$s[Shortcode]%2$s to the %3$sSingle Post Sidebar%4$s. Failing to do so may result in the author status not being displayed.',
                                        'wp-author-status'
                                    ),
                                    '<strong>', '</strong>', '<strong>', '</strong>'
                                );
								?>
							</li>
						</ol>
					</li>
					<li>
						<strong><?php esc_html_e('Using the "status" Attribute in the Shortcode:', 'wp-author-status'); ?></strong>
						<ol>
							<li>
								<?php
									printf(
										/* translators: 1: Opening strong tag, 2: Closing strong tag */
										esc_html__( 'The %1$s[wp-author-status]%2$s shortcode includes an optional status attribute. If you provide a value for this attribute, the specified text will appear as the author status, overriding any saved status for the user.', 'wp-author-status' ),
										'<strong>', '</strong>'
									); 
								?>
								<p>
									<strong><?php esc_html_e('Example:', 'wp-author-status'); ?></strong><br><br>
									<?php
										printf(
											/* translators: %1$s and %4$s: Opening and closing <code> tags, %2$s and %3$s: Opening and closing <span> tags for function name. */
											esc_html__( '%1$s[wp-author-status %2$sstatus%3$s="Hello, this is my custom status!"]%4$s', 'wp-author-status' ),
											'<code>', '<span class="wpaust-function">', '</span>', '</code>'
										);
									?>
								</p>
							</li>
							<li><?php esc_html_e( 'If you include the "status" attribute, the shortcode will display the provided status text.', 'wp-author-status' ); ?></li>
							<li><?php esc_html_e( 'If the status attribute is omitted, the system will fetch and display the saved author status from the database, or show a placeholder if no status is available.', 'wp-author-status' ); ?></li>
						</ol>
					</li>
                    <li>
                        <strong><?php esc_html_e('Using the "colors" Attribute in the Shortcode:', 'wp-author-status'); ?></strong>
                        <ol>
                            <li>
                                <?php
                                    printf(
                                        /* translators: 1: Opening strong tag, 2: Closing strong tag */
                                        esc_html__( 'The %1$s[wp-author-status]%2$s shortcode includes an optional colors attribute. If you provide a value for this attribute, the specified color combination will be applied to the author status display.', 'wp-author-status' ),
                                        '<strong>', '</strong>'
                                    );
                                ?>
                                <p>
                                    <strong><?php esc_html_e('Example:', 'wp-author-status'); ?></strong><br><br>
                                    <?php
                                        printf(
                                            /* translators: %1$s and %4$s: Opening and closing <code> tags, %2$s and %3$s: Opening and closing <span> tags for attribute. */
                                            esc_html__( '%1$s[wp-author-status colors=%2$s"bp"%3$s]%4$s', 'wp-author-status' ),
                                            '<code>', '<span class="wpaust-function">', '</span>', '</code>'
                                        );
                                    ?>
                                </p>
                            </li>
                            <li><?php esc_html_e( 'If you include the "colors" attribute, the shortcode will display the author status with the chosen color combination.', 'wp-author-status' ); ?></li>
                            <li><?php esc_html_e( 'The available color combinations are:', 'wp-author-status' ); ?>
                                <ul>
                                    <li><?php esc_html_e( 'bp - Blue, Purple', 'wp-author-status' ); ?></li>
                                    <li><?php esc_html_e( 'tb - Teal, Blue', 'wp-author-status' ); ?></li>
                                    <li><?php esc_html_e( 'gy - Green, Yellow', 'wp-author-status' ); ?></li>
                                    <li><?php esc_html_e( 'dp - Dark Purple, Light Purple', 'wp-author-status' ); ?></li>
                                    <li><?php esc_html_e( 'db - Dark Blue, Light Blue', 'wp-author-status' ); ?></li>
                                </ul>
                            </li>
                            <li><?php esc_html_e( 'If the "colors" attribute is omitted, the default color combination (Blue, Purple) will be used.', 'wp-author-status' ); ?></li>
                        </ol>
                    </li>
				</ol>
			</div>
			<?php
		}

		/**
		 * Render the sidebar.
		 */
		private function render_sidebar() {
			if (class_exists('WPAUST_Sidebar')) {
				$wpaust_sidebar = WPAUST_Sidebar::get_instances();
				if (method_exists($wpaust_sidebar, 'wpaust_sidebar')) {
					// Render sidebar content
					$sidebar_content = $wpaust_sidebar->wpaust_sidebar();
					if ( $sidebar_content !== null ) {
						echo wp_kses_post( $sidebar_content );
					} else {
						// Fallback for null content
						echo ''; // or provide alternative content if needed
					}
				}
			}
		}
    }
}