<?php
/**
 * Plugin Name:         RWC Author Status - Let Authors Share Their Voice
 * Plugin URI:          https://realwebcare.com/
 * Description:         Display author status easily in WordPress posts, letting authors share their thoughts and updates on every post.
 * Version:             2.0
 * Requires at least:   5.2
 * Requires PHP:        7.4
 * Author:              Realwebcare
 * Author URI:          https://www.realwebcare.com/
 * Text Domain:         wp-author-status
 * Domain Path:         /languages
 * License:             GPL v2 or later
 * License URI:         http://www.gnu.org/licenses/gpl-2.0.html
 */
if ( ! defined('ABSPATH') ) {
    exit;
}

/**
 * Class WPAUST_Init
 *
 * @package WP Author Status v2.0 - 30 January, 2025
 * @link https://www.realwebcare.com/
 */

if ( ! class_exists('WPAUST_Init') ) {
    class WPAUST_Init {

        private static $instance;

        private function __construct() {
            // Define plugin-specific constants.
            $this->define_constants();

            // Load necessary required files.
            $this->required_files();
        }

        public static function get_instances() {
            if ( self::$instance ) {
                return self::$instance;
            }

            self::$instance = new self();

            return self::$instance;
        }

        /**
         * Defines essential plugin constants.
         *
         * This method sets up constants that are used throughout the plugin for easy access 
         * to important paths and URLs, ensuring a consistent and maintainable structure.
         *
         * @return void
         */
        private function define_constants() {
            define( 'WPAUST_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
            define( 'WPAUST_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
            define( 'WPAUST_AUF', __FILE__ );
        }

        /**
         * Includes required files for the plugin's functionality.
         *
         * @return void
         */
        private function required_files() {
            // Contains options and settings logic for the plugin.
            require_once WPAUST_PLUGIN_PATH . 'includes/wpaust-process.php';
        }
    }
}

WPAUST_Init::get_instances();